Structs
- Cached
Extraction Failure - Entity
- Extraction
Client - Extraction
Report - GitChanged
Files - Relationship
- Summarize
Config - Summary
- Summary
Cache - Summary
Cache Lookup - Summary
Db - Summary
File Snapshot - Summary
Read Only Open - Summary
Stats - Summary
Stats Warning - Summary
Write Lock Guard
Enums
Functions
- acquire_
write_ lock - content_
hash - extract_
for_ file - extract_
for_ file_ with_ client - file_
lookup_ candidates - git_
changed_ files - has_
extraction_ content - Whether already-read source bytes contain content worth sending to a model.
- is_
extraction_ candidate_ file - Whether a live file can produce a useful extraction. Empty source files have no summary to ask a model for and must not consume a request.
- is_
extraction_ candidate_ path - normalize_
lexical_ path - normalize_
summary_ file_ key - normalize_
summary_ file_ key_ str - terminal_
extraction_ failure - writer_
lock_ path